@@ -26,7 +26,7 @@ disassoc()
 	(void) open("/", O_RDONLY, 0);
 	(void) dup2(0, 1);
 	(void) dup2(0, 2);
-#if defined hpux || defined SVR4
+#if defined hpux || defined Rel4
 	setsid();
 #else
 	i = open("/dev/tty", O_RDWR, 0);
