@@ -80,8 +80,8 @@ void lwpReschedule()
 {
 	extern struct lwpQueue LwpSchedQ[];
 	static int lcount = LCOUNT;
-	register struct lwpProc *nextp;
-	register int i;
+	static struct lwpProc *nextp;
+	static int i;
 #ifdef POSIXSIGNALS
 	static sigset_t tmask;
 #endif /* POSIXSIGNALS */
