@@ -204,6 +204,7 @@ landrepair(land, vec, np, bp, etus)
 	int	w_p_eff;
 	int	mult;
 	int	svec[I_MAX+1];
+	int     mvec[I_MAX+1];
 
 	lp = &lchr[land->lnd_type];
 	sp = getsectp(land->lnd_x, land->lnd_y);
@@ -240,196 +241,40 @@ landrepair(land, vec, np, bp, etus)
 		left = delta;
 
         leftp = ((float)left/100.0);
-        mil_needed = ldround((double)(lp->l_mil * leftp),1);
-        lcm_needed = ldround((double)(lp->l_lcm * leftp),1);
-        hcm_needed = ldround((double)(lp->l_hcm * leftp),1);
-        gun_needed = ldround((double)(lp->l_gun * leftp),1);
-        shell_needed = ldround((double)(lp->l_shell * leftp),1);
 
-	if (opt_GRAB_THINGS) {
-		/* try_supply_commod will get from this sect first, then look
-		 * elsewhere until it finds what it needs. It'll return the
-		 * number of mil/lcm/hcm/etc it finds available without
-		 * actually getting it
-		 */
+	bzero(mvec, sizeof(mvec));
+        mvec[I_MILIT] = mil_needed = ldround((double)(lp->l_mil * leftp),1);
+        mvec[I_LCM] = lcm_needed = ldround((double)(lp->l_lcm * leftp),1);
+        mvec[I_HCM] = hcm_needed = ldround((double)(lp->l_hcm * leftp),1);
+        mvec[I_GUN] = gun_needed = ldround((double)(lp->l_gun * leftp),1);
+        mvec[I_SHELL] = shell_needed = ldround((double)(lp->l_shell * leftp),1);
 
-		getvec(VT_ITEM, vec, (s_char *)land, EF_LAND);
-		mil = vec[I_MILIT];
-		lcm = vec[I_LCM];
-		hcm = vec[I_HCM];
-		gun = vec[I_GUN];
-		shell = vec[I_SHELL];
+	get_materials(sp, bp, mvec, 0);
 
-		mil += try_supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,I_MILIT,
-					 mil_needed-mil);
-		lcm += try_supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,I_LCM,
-					 lcm_needed-lcm);
-		hcm += try_supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,I_HCM,
-					 hcm_needed-hcm);
-		gun += try_supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,I_GUN,
-					 gun_needed-gun);
-		shell += try_supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,I_SHELL,
-					   shell_needed-shell);
-	}
-	else			/* ! GRAB_THINGS */
-	{
-	        if (update_pending) {
-		   mil = svec[I_MILIT];
-		   lcm = svec[I_LCM];
-		   hcm = svec[I_HCM];
-		   gun = svec[I_GUN];
-		   shell = svec[I_SHELL];
-		} else {
-		   mil = gt_bg_nmbr(bp, sp, I_MILIT);
-		   lcm = gt_bg_nmbr(bp, sp, I_LCM);
-		   hcm = gt_bg_nmbr(bp, sp, I_HCM);
-		   gun = gt_bg_nmbr(bp, sp, I_GUN);
-		   shell = gt_bg_nmbr(bp, sp, I_SHELL);
-		}
-	} /* end GRAB_THINGS */
-
-        if (mil>=mil_needed)
+        if (mvec[I_MILIT]>=mil_needed)
                 buildp=leftp;
         else
-                buildp=((float)mil/(float)lp->l_mil);
-        if (lcm < lcm_needed)
-                buildp = MIN(buildp,((float)lcm/(float)lp->l_lcm));
-        if (hcm < hcm_needed)
-                buildp = MIN(buildp,((float)hcm/(float)lp->l_hcm));
-        if (gun < gun_needed)
-		buildp = MIN(buildp,((float)gun/(float)lp->l_gun));
-        if (shell < shell_needed)
-                buildp = MIN(buildp,((float)shell/(float)lp->l_shell));
+                buildp=((float)mvec[I_MILIT]/(float)lp->l_mil);
+        if (mvec[I_LCM] < lcm_needed)
+                buildp = MIN(buildp,((float)mvec[I_LCM]/(float)lp->l_lcm));
+        if (mvec[I_HCM] < hcm_needed)
+                buildp = MIN(buildp,((float)mvec[I_HCM]/(float)lp->l_hcm));
+        if (mvec[I_GUN] < gun_needed)
+		buildp = MIN(buildp,((float)mvec[I_GUN]/(float)lp->l_gun));
+        if (mvec[I_SHELL] < shell_needed)
+                buildp = MIN(buildp,((float)mvec[I_SHELL]/(float)lp->l_shell));
 
 	build=ldround((double)(buildp*100.0),1);
 
-        mil_needed = roundavg((double)(lp->l_mil * buildp));
-        lcm_needed = roundavg((double)(lp->l_lcm * buildp));
-        hcm_needed = roundavg((double)(lp->l_hcm * buildp));
-        gun_needed = roundavg((double)(lp->l_gun * buildp));
-        shell_needed = roundavg((double)(lp->l_shell * buildp));
+	bzero(mvec, sizeof(mvec));
+        mvec[I_MILIT] = mil_needed = roundavg((double)(lp->l_mil * buildp));
+        mvec[I_LCM] = lcm_needed = roundavg((double)(lp->l_lcm * buildp));
+        mvec[I_HCM] = hcm_needed = roundavg((double)(lp->l_hcm * buildp));
+        mvec[I_GUN] = gun_needed = roundavg((double)(lp->l_gun * buildp));
+        mvec[I_SHELL] = shell_needed = roundavg((double)(lp->l_shell * buildp));
 	mil_dbl_pay += mil_needed;
 
-	if (opt_GRAB_THINGS) {
-		/*
-		 * Now that we know how much we can actually use, get it.
-		 * supply_commod will actually subtract the commod off the
-		 * sector/ship/supply unit
-		 */
-	        if (update_pending) {
-		   mil = vec[I_MILIT];
-		   lcm = vec[I_LCM];
-		   hcm = vec[I_HCM];
-		   gun = vec[I_GUN];
-		   shell = vec[I_SHELL];
-		} else {
-		   omil = vec[I_MILIT];
-		   olcm = vec[I_LCM];
-		   ohcm = vec[I_HCM];
-		   ogun = vec[I_GUN];
-		   oshell = vec[I_SHELL];
-		   mil = gt_bg_nmbr(bp, sp, I_MILIT);
-		   lcm = gt_bg_nmbr(bp, sp, I_LCM);
-		   hcm = gt_bg_nmbr(bp, sp, I_HCM);
-		   gun = gt_bg_nmbr(bp, sp, I_GUN);
-		   shell = gt_bg_nmbr(bp, sp, I_SHELL);
-		}
-
-		/* Take the commods off so supply_commod doesn't grab them */
-		/* keepmil, etc are how many they should have afterwards   */
-		keepmil=(mil-mil_needed > 0 ? mil-mil_needed : 0);
-		keeplcm=(lcm-lcm_needed > 0 ? lcm-lcm_needed : 0);
-		keephcm=(hcm-hcm_needed > 0 ? hcm-hcm_needed : 0);
-		keepgun=(gun-gun_needed > 0 ? gun-gun_needed : 0);
-		keepshell=(shell-shell_needed > 0 ? shell-shell_needed : 0);
-		vec[I_MILIT]=0;
-		vec[I_LCM]=0;
-		vec[I_HCM]=0;
-		vec[I_GUN]=0;
-		vec[I_SHELL]=0;
-
-		putvec(VT_ITEM, vec, (s_char *)land, EF_LAND);
-
-		mil += supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,I_MILIT,
-				     mil_needed-mil);
-		lcm += supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,I_LCM,
-				     lcm_needed-lcm);
-		hcm += supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,I_HCM,
-				     hcm_needed-hcm);
-		gun += supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,I_GUN,
-				     gun_needed-gun);
-		shell += supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,I_SHELL,
-				       shell_needed-shell);
-
-		if (update_pending) {
-		   vec[I_MILIT]=keepmil;
-		   vec[I_LCM]=keeplcm;
-		   vec[I_HCM]=keephcm;
-		   vec[I_GUN]=keepgun;
-		   vec[I_SHELL]=keepshell;
-		} else {
-		   vec[I_MILIT] = omil;
-		   vec[I_LCM] = olcm;
-		   vec[I_HCM] = ohcm;
-		   vec[I_GUN] = ogun;
-		   vec[I_SHELL] = oshell;
-		}
-
-		   putvec(VT_ITEM, vec, (s_char *)land, EF_LAND);
-	    
-		/*
-		 * get the sect again, so we don't
-		 * overwrite it if supply_commod changed it
-		 */
-		sp = getsectp(land->lnd_x, land->lnd_y);
-	}
-	else			/* don't GRAB_THINGS */
-	{
-	        if (update_pending) {
-		   if ((svec[I_MILIT] - mil_needed) < 0)
-		      svec[I_MILIT] = 0;
-		   else
-		      svec[I_MILIT] -= mil_needed;
-		   if ((svec[I_LCM] - lcm_needed) < 0)
-		      svec[I_LCM] = 0;
-		   else
-		      svec[I_LCM] -= lcm_needed;
-		   if ((svec[I_HCM] - hcm_needed) < 0)
-		      svec[I_HCM] = 0;
-		   else
-		      svec[I_HCM] -= hcm_needed;
-		   if ((svec[I_GUN] - gun_needed) < 0)
-		      svec[I_GUN] = 0;
-		   else
-		      svec[I_GUN] -= gun_needed;
-		   if ((svec[I_SHELL] - shell_needed) < 0)
-		      svec[I_SHELL] = 0;
-		   else
-		      svec[I_SHELL] -= shell_needed;
-		   putvec(VT_ITEM, svec, (s_char *)sp, EF_SECTOR);
-		} else {
-		   if ((gt_bg_nmbr(bp, sp, I_MILIT) - mil_needed) < 0)
-		      pt_bg_nmbr(bp, sp, I_MILIT, 0);
-		   else
-		      pt_bg_nmbr(bp, sp, I_MILIT, gt_bg_nmbr(bp, sp, I_MILIT) - mil_needed);
-		   if ((gt_bg_nmbr(bp, sp, I_LCM) - lcm_needed) < 0)
-		      pt_bg_nmbr(bp, sp, I_LCM, 0);
-		   else
-		      pt_bg_nmbr(bp, sp, I_LCM, gt_bg_nmbr(bp, sp, I_LCM) - lcm_needed);
-		   if ((gt_bg_nmbr(bp, sp, I_HCM) - hcm_needed) < 0)
-		      pt_bg_nmbr(bp, sp, I_HCM, 0);
-		   else
-		      pt_bg_nmbr(bp, sp, I_HCM, gt_bg_nmbr(bp, sp, I_HCM) - hcm_needed);
-		   if ((gt_bg_nmbr(bp, sp, I_GUN) - gun_needed) < 0)
-		      pt_bg_nmbr(bp, sp, I_GUN, 0);
-		   else
-		      pt_bg_nmbr(bp, sp, I_GUN, gt_bg_nmbr(bp, sp, I_GUN) - gun_needed);
-		   if ((gt_bg_nmbr(bp, sp, I_SHELL) - shell_needed) < 0)
-		      pt_bg_nmbr(bp, sp, I_SHELL, 0);
-		   else
-		      pt_bg_nmbr(bp, sp, I_SHELL, gt_bg_nmbr(bp, sp, I_SHELL) - shell_needed);
-		}
-	}
+	get_materials(sp, bp, mvec, 1);
 
 	if ((sp->sct_type != SCT_HEADQ) && (sp->sct_type != SCT_FORTR))
 		build /= 3;
