@@ -22,7 +22,7 @@ static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/update/
 #include "land.h"
 #include "budg.h"
 
-double
+void
 populace(np, sp, vec, etu)
 	struct	natstr *np;
 	register struct sctstr *sp;
@@ -47,17 +47,12 @@ populace(np, sp, vec, etu)
 		!has_units(sp->sct_x,sp->sct_y,sp->sct_own)) {
 		sp->sct_own = 0;
 		sp->sct_oldown = 0;
-		return 0.0;
+		return;
 	}
 	if (sp->sct_own != sp->sct_oldown && sp->sct_loyal == 0) {
 		sp->sct_oldown = sp->sct_own;
 	}
-	/*
-	 * collect the taxes, and pay the troops
-	 */
-	
-	taxes = (int) (civ_taxes(vec[I_CIVIL], sp->sct_effic) + uw_taxes(vec[I_UW], sp->sct_effic) + mil_payment(vec[I_MILIT]));
-	np->nat_money += (int) taxes;
+
 	hap = np->nat_level[NAT_HLEV];
 	edu = np->nat_level[NAT_ELEV];
 	tech = np->nat_level[NAT_TLEV];
@@ -113,26 +108,15 @@ populace(np, sp, vec, etu)
 			sp->sct_loyal = 0;
 		}
 	}
-	return (vec[I_CIVIL] * sp->sct_work) / 100.0 +
-		(vec[I_MILIT] * 2 / 5.0) + vec[I_UW];
+	return;
 }
 
-/*
- * percentage of people who starved
- */
 int
-starvation(sp)
-	struct	sctstr *sp;
+total_work(sctwork, etu, civil, milit, uw)
+register int sctwork;
+register int etu;
+register int civil, milit, uw;
 {
-	sp->sct_work = 0;
-	sp->sct_loyal += (random() % 8) + 2;
-}
-
-double
-total_work(sp, vec)
-register struct sctstr *sp;
-register int *vec;
-{
-	return ((double)((vec[I_CIVIL] * sp->sct_work) / 100.0 +
-		(vec[I_MILIT] * 2 / 5.0) + vec[I_UW]));
+	return ((int)((((civil * sctwork) / 100.0 +
+		(milit * 2 / 5.0) + uw)) * etu) / 100);
 }
